# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .login import (
    LoginResource,
    AsyncLoginResource,
    LoginResourceWithRawResponse,
    AsyncLoginResourceWithRawResponse,
    LoginResourceWithStreamingResponse,
    AsyncLoginResourceWithStreamingResponse,
)
from ...._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from .number_2fa import (
    Number2faResource,
    AsyncNumber2faResource,
    Number2faResourceWithRawResponse,
    AsyncNumber2faResourceWithRawResponse,
    Number2faResourceWithStreamingResponse,
    AsyncNumber2faResourceWithStreamingResponse,
)
from ....types.v1 import auth_reset_password_params, auth_register_new_user_params, auth_request_password_reset_params
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from .organization_invites import (
    OrganizationInvitesResource,
    AsyncOrganizationInvitesResource,
    OrganizationInvitesResourceWithRawResponse,
    AsyncOrganizationInvitesResourceWithRawResponse,
    OrganizationInvitesResourceWithStreamingResponse,
    AsyncOrganizationInvitesResourceWithStreamingResponse,
)

__all__ = ["AuthResource", "AsyncAuthResource"]


class AuthResource(SyncAPIResource):
    @cached_property
    def login(self) -> LoginResource:
        return LoginResource(self._client)

    @cached_property
    def number_2fa(self) -> Number2faResource:
        return Number2faResource(self._client)

    @cached_property
    def organization_invites(self) -> OrganizationInvitesResource:
        return OrganizationInvitesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AuthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/GoStudyFetchGo/studyfetch-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AuthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AuthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/GoStudyFetchGo/studyfetch-sdk-python#with_streaming_response
        """
        return AuthResourceWithStreamingResponse(self)

    def get_profile(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/api/v1/auth/profile",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def register_new_user(
        self,
        *,
        email: str,
        name: str,
        organization_name: str,
        password: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          email: User email address

          name: User full name

          organization_name: Organization name

          password: User password

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/api/v1/auth/register",
            body=maybe_transform(
                {
                    "email": email,
                    "name": name,
                    "organization_name": organization_name,
                    "password": password,
                },
                auth_register_new_user_params.AuthRegisterNewUserParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def register_organization(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/api/v1/auth/register-organization",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def register_with_invite(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/api/v1/auth/register-with-invite",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def request_password_reset(
        self,
        *,
        email: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          email: Email address to send reset link

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/api/v1/auth/forgot-password",
            body=maybe_transform({"email": email}, auth_request_password_reset_params.AuthRequestPasswordResetParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def reset_password(
        self,
        *,
        token: str,
        new_password: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          token: Password reset token from email

          new_password: New password

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/api/v1/auth/reset-password",
            body=maybe_transform(
                {
                    "token": token,
                    "new_password": new_password,
                },
                auth_reset_password_params.AuthResetPasswordParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAuthResource(AsyncAPIResource):
    @cached_property
    def login(self) -> AsyncLoginResource:
        return AsyncLoginResource(self._client)

    @cached_property
    def number_2fa(self) -> AsyncNumber2faResource:
        return AsyncNumber2faResource(self._client)

    @cached_property
    def organization_invites(self) -> AsyncOrganizationInvitesResource:
        return AsyncOrganizationInvitesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncAuthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/GoStudyFetchGo/studyfetch-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAuthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAuthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/GoStudyFetchGo/studyfetch-sdk-python#with_streaming_response
        """
        return AsyncAuthResourceWithStreamingResponse(self)

    async def get_profile(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/api/v1/auth/profile",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def register_new_user(
        self,
        *,
        email: str,
        name: str,
        organization_name: str,
        password: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          email: User email address

          name: User full name

          organization_name: Organization name

          password: User password

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/api/v1/auth/register",
            body=await async_maybe_transform(
                {
                    "email": email,
                    "name": name,
                    "organization_name": organization_name,
                    "password": password,
                },
                auth_register_new_user_params.AuthRegisterNewUserParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def register_organization(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/api/v1/auth/register-organization",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def register_with_invite(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/api/v1/auth/register-with-invite",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def request_password_reset(
        self,
        *,
        email: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          email: Email address to send reset link

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/api/v1/auth/forgot-password",
            body=await async_maybe_transform(
                {"email": email}, auth_request_password_reset_params.AuthRequestPasswordResetParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def reset_password(
        self,
        *,
        token: str,
        new_password: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          token: Password reset token from email

          new_password: New password

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/api/v1/auth/reset-password",
            body=await async_maybe_transform(
                {
                    "token": token,
                    "new_password": new_password,
                },
                auth_reset_password_params.AuthResetPasswordParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AuthResourceWithRawResponse:
    def __init__(self, auth: AuthResource) -> None:
        self._auth = auth

        self.get_profile = to_raw_response_wrapper(
            auth.get_profile,
        )
        self.register_new_user = to_raw_response_wrapper(
            auth.register_new_user,
        )
        self.register_organization = to_raw_response_wrapper(
            auth.register_organization,
        )
        self.register_with_invite = to_raw_response_wrapper(
            auth.register_with_invite,
        )
        self.request_password_reset = to_raw_response_wrapper(
            auth.request_password_reset,
        )
        self.reset_password = to_raw_response_wrapper(
            auth.reset_password,
        )

    @cached_property
    def login(self) -> LoginResourceWithRawResponse:
        return LoginResourceWithRawResponse(self._auth.login)

    @cached_property
    def number_2fa(self) -> Number2faResourceWithRawResponse:
        return Number2faResourceWithRawResponse(self._auth.number_2fa)

    @cached_property
    def organization_invites(self) -> OrganizationInvitesResourceWithRawResponse:
        return OrganizationInvitesResourceWithRawResponse(self._auth.organization_invites)


class AsyncAuthResourceWithRawResponse:
    def __init__(self, auth: AsyncAuthResource) -> None:
        self._auth = auth

        self.get_profile = async_to_raw_response_wrapper(
            auth.get_profile,
        )
        self.register_new_user = async_to_raw_response_wrapper(
            auth.register_new_user,
        )
        self.register_organization = async_to_raw_response_wrapper(
            auth.register_organization,
        )
        self.register_with_invite = async_to_raw_response_wrapper(
            auth.register_with_invite,
        )
        self.request_password_reset = async_to_raw_response_wrapper(
            auth.request_password_reset,
        )
        self.reset_password = async_to_raw_response_wrapper(
            auth.reset_password,
        )

    @cached_property
    def login(self) -> AsyncLoginResourceWithRawResponse:
        return AsyncLoginResourceWithRawResponse(self._auth.login)

    @cached_property
    def number_2fa(self) -> AsyncNumber2faResourceWithRawResponse:
        return AsyncNumber2faResourceWithRawResponse(self._auth.number_2fa)

    @cached_property
    def organization_invites(self) -> AsyncOrganizationInvitesResourceWithRawResponse:
        return AsyncOrganizationInvitesResourceWithRawResponse(self._auth.organization_invites)


class AuthResourceWithStreamingResponse:
    def __init__(self, auth: AuthResource) -> None:
        self._auth = auth

        self.get_profile = to_streamed_response_wrapper(
            auth.get_profile,
        )
        self.register_new_user = to_streamed_response_wrapper(
            auth.register_new_user,
        )
        self.register_organization = to_streamed_response_wrapper(
            auth.register_organization,
        )
        self.register_with_invite = to_streamed_response_wrapper(
            auth.register_with_invite,
        )
        self.request_password_reset = to_streamed_response_wrapper(
            auth.request_password_reset,
        )
        self.reset_password = to_streamed_response_wrapper(
            auth.reset_password,
        )

    @cached_property
    def login(self) -> LoginResourceWithStreamingResponse:
        return LoginResourceWithStreamingResponse(self._auth.login)

    @cached_property
    def number_2fa(self) -> Number2faResourceWithStreamingResponse:
        return Number2faResourceWithStreamingResponse(self._auth.number_2fa)

    @cached_property
    def organization_invites(self) -> OrganizationInvitesResourceWithStreamingResponse:
        return OrganizationInvitesResourceWithStreamingResponse(self._auth.organization_invites)


class AsyncAuthResourceWithStreamingResponse:
    def __init__(self, auth: AsyncAuthResource) -> None:
        self._auth = auth

        self.get_profile = async_to_streamed_response_wrapper(
            auth.get_profile,
        )
        self.register_new_user = async_to_streamed_response_wrapper(
            auth.register_new_user,
        )
        self.register_organization = async_to_streamed_response_wrapper(
            auth.register_organization,
        )
        self.register_with_invite = async_to_streamed_response_wrapper(
            auth.register_with_invite,
        )
        self.request_password_reset = async_to_streamed_response_wrapper(
            auth.request_password_reset,
        )
        self.reset_password = async_to_streamed_response_wrapper(
            auth.reset_password,
        )

    @cached_property
    def login(self) -> AsyncLoginResourceWithStreamingResponse:
        return AsyncLoginResourceWithStreamingResponse(self._auth.login)

    @cached_property
    def number_2fa(self) -> AsyncNumber2faResourceWithStreamingResponse:
        return AsyncNumber2faResourceWithStreamingResponse(self._auth.number_2fa)

    @cached_property
    def organization_invites(self) -> AsyncOrganizationInvitesResourceWithStreamingResponse:
        return AsyncOrganizationInvitesResourceWithStreamingResponse(self._auth.organization_invites)
