# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options

__all__ = ["OrganizationInvitesResource", "AsyncOrganizationInvitesResource"]


class OrganizationInvitesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OrganizationInvitesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/GoStudyFetchGo/studyfetch-sdk-python#accessing-raw-response-data-eg-headers
        """
        return OrganizationInvitesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OrganizationInvitesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/GoStudyFetchGo/studyfetch-sdk-python#with_streaming_response
        """
        return OrganizationInvitesResourceWithStreamingResponse(self)

    def preview(
        self,
        token: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not token:
            raise ValueError(f"Expected a non-empty value for `token` but received {token!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/api/v1/auth/organization-invites/preview/{token}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncOrganizationInvitesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOrganizationInvitesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/GoStudyFetchGo/studyfetch-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncOrganizationInvitesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOrganizationInvitesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/GoStudyFetchGo/studyfetch-sdk-python#with_streaming_response
        """
        return AsyncOrganizationInvitesResourceWithStreamingResponse(self)

    async def preview(
        self,
        token: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not token:
            raise ValueError(f"Expected a non-empty value for `token` but received {token!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/api/v1/auth/organization-invites/preview/{token}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class OrganizationInvitesResourceWithRawResponse:
    def __init__(self, organization_invites: OrganizationInvitesResource) -> None:
        self._organization_invites = organization_invites

        self.preview = to_raw_response_wrapper(
            organization_invites.preview,
        )


class AsyncOrganizationInvitesResourceWithRawResponse:
    def __init__(self, organization_invites: AsyncOrganizationInvitesResource) -> None:
        self._organization_invites = organization_invites

        self.preview = async_to_raw_response_wrapper(
            organization_invites.preview,
        )


class OrganizationInvitesResourceWithStreamingResponse:
    def __init__(self, organization_invites: OrganizationInvitesResource) -> None:
        self._organization_invites = organization_invites

        self.preview = to_streamed_response_wrapper(
            organization_invites.preview,
        )


class AsyncOrganizationInvitesResourceWithStreamingResponse:
    def __init__(self, organization_invites: AsyncOrganizationInvitesResource) -> None:
        self._organization_invites = organization_invites

        self.preview = async_to_streamed_response_wrapper(
            organization_invites.preview,
        )
