# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSections:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_retrieve(self, client: StudyfetchSDK) -> None:
        section = client.v1.audio_recaps.sections.retrieve(
            section_id="sectionId",
            recap_id="recapId",
        )
        assert section is None

    @parametrize
    def test_raw_response_retrieve(self, client: StudyfetchSDK) -> None:
        response = client.v1.audio_recaps.sections.with_raw_response.retrieve(
            section_id="sectionId",
            recap_id="recapId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        section = response.parse()
        assert section is None

    @parametrize
    def test_streaming_response_retrieve(self, client: StudyfetchSDK) -> None:
        with client.v1.audio_recaps.sections.with_streaming_response.retrieve(
            section_id="sectionId",
            recap_id="recapId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            section = response.parse()
            assert section is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `recap_id` but received ''"):
            client.v1.audio_recaps.sections.with_raw_response.retrieve(
                section_id="sectionId",
                recap_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `section_id` but received ''"):
            client.v1.audio_recaps.sections.with_raw_response.retrieve(
                section_id="",
                recap_id="recapId",
            )

    @parametrize
    def test_method_list(self, client: StudyfetchSDK) -> None:
        section = client.v1.audio_recaps.sections.list(
            "recapId",
        )
        assert section is None

    @parametrize
    def test_raw_response_list(self, client: StudyfetchSDK) -> None:
        response = client.v1.audio_recaps.sections.with_raw_response.list(
            "recapId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        section = response.parse()
        assert section is None

    @parametrize
    def test_streaming_response_list(self, client: StudyfetchSDK) -> None:
        with client.v1.audio_recaps.sections.with_streaming_response.list(
            "recapId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            section = response.parse()
            assert section is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `recap_id` but received ''"):
            client.v1.audio_recaps.sections.with_raw_response.list(
                "",
            )


class TestAsyncSections:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        section = await async_client.v1.audio_recaps.sections.retrieve(
            section_id="sectionId",
            recap_id="recapId",
        )
        assert section is None

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.audio_recaps.sections.with_raw_response.retrieve(
            section_id="sectionId",
            recap_id="recapId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        section = await response.parse()
        assert section is None

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.audio_recaps.sections.with_streaming_response.retrieve(
            section_id="sectionId",
            recap_id="recapId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            section = await response.parse()
            assert section is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `recap_id` but received ''"):
            await async_client.v1.audio_recaps.sections.with_raw_response.retrieve(
                section_id="sectionId",
                recap_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `section_id` but received ''"):
            await async_client.v1.audio_recaps.sections.with_raw_response.retrieve(
                section_id="",
                recap_id="recapId",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncStudyfetchSDK) -> None:
        section = await async_client.v1.audio_recaps.sections.list(
            "recapId",
        )
        assert section is None

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.audio_recaps.sections.with_raw_response.list(
            "recapId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        section = await response.parse()
        assert section is None

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.audio_recaps.sections.with_streaming_response.list(
            "recapId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            section = await response.parse()
            assert section is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `recap_id` but received ''"):
            await async_client.v1.audio_recaps.sections.with_raw_response.list(
                "",
            )
