# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestLogin:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_authenticate(self, client: StudyfetchSDK) -> None:
        login = client.v1.auth.login.authenticate(
            email="user@example.com",
            password="password123",
        )
        assert login is None

    @parametrize
    def test_raw_response_authenticate(self, client: StudyfetchSDK) -> None:
        response = client.v1.auth.login.with_raw_response.authenticate(
            email="user@example.com",
            password="password123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        login = response.parse()
        assert login is None

    @parametrize
    def test_streaming_response_authenticate(self, client: StudyfetchSDK) -> None:
        with client.v1.auth.login.with_streaming_response.authenticate(
            email="user@example.com",
            password="password123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            login = response.parse()
            assert login is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_verify_2fa(self, client: StudyfetchSDK) -> None:
        login = client.v1.auth.login.verify_2fa(
            code="123456",
            email="user@example.com",
        )
        assert login is None

    @parametrize
    def test_raw_response_verify_2fa(self, client: StudyfetchSDK) -> None:
        response = client.v1.auth.login.with_raw_response.verify_2fa(
            code="123456",
            email="user@example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        login = response.parse()
        assert login is None

    @parametrize
    def test_streaming_response_verify_2fa(self, client: StudyfetchSDK) -> None:
        with client.v1.auth.login.with_streaming_response.verify_2fa(
            code="123456",
            email="user@example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            login = response.parse()
            assert login is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_verify_backup_code(self, client: StudyfetchSDK) -> None:
        login = client.v1.auth.login.verify_backup_code(
            backup_code="ABCD-EFGH-IJKL",
            email="user@example.com",
        )
        assert login is None

    @parametrize
    def test_raw_response_verify_backup_code(self, client: StudyfetchSDK) -> None:
        response = client.v1.auth.login.with_raw_response.verify_backup_code(
            backup_code="ABCD-EFGH-IJKL",
            email="user@example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        login = response.parse()
        assert login is None

    @parametrize
    def test_streaming_response_verify_backup_code(self, client: StudyfetchSDK) -> None:
        with client.v1.auth.login.with_streaming_response.verify_backup_code(
            backup_code="ABCD-EFGH-IJKL",
            email="user@example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            login = response.parse()
            assert login is None

        assert cast(Any, response.is_closed) is True


class TestAsyncLogin:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_authenticate(self, async_client: AsyncStudyfetchSDK) -> None:
        login = await async_client.v1.auth.login.authenticate(
            email="user@example.com",
            password="password123",
        )
        assert login is None

    @parametrize
    async def test_raw_response_authenticate(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.auth.login.with_raw_response.authenticate(
            email="user@example.com",
            password="password123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        login = await response.parse()
        assert login is None

    @parametrize
    async def test_streaming_response_authenticate(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.auth.login.with_streaming_response.authenticate(
            email="user@example.com",
            password="password123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            login = await response.parse()
            assert login is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_verify_2fa(self, async_client: AsyncStudyfetchSDK) -> None:
        login = await async_client.v1.auth.login.verify_2fa(
            code="123456",
            email="user@example.com",
        )
        assert login is None

    @parametrize
    async def test_raw_response_verify_2fa(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.auth.login.with_raw_response.verify_2fa(
            code="123456",
            email="user@example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        login = await response.parse()
        assert login is None

    @parametrize
    async def test_streaming_response_verify_2fa(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.auth.login.with_streaming_response.verify_2fa(
            code="123456",
            email="user@example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            login = await response.parse()
            assert login is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_verify_backup_code(self, async_client: AsyncStudyfetchSDK) -> None:
        login = await async_client.v1.auth.login.verify_backup_code(
            backup_code="ABCD-EFGH-IJKL",
            email="user@example.com",
        )
        assert login is None

    @parametrize
    async def test_raw_response_verify_backup_code(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.auth.login.with_raw_response.verify_backup_code(
            backup_code="ABCD-EFGH-IJKL",
            email="user@example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        login = await response.parse()
        assert login is None

    @parametrize
    async def test_streaming_response_verify_backup_code(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.auth.login.with_streaming_response.verify_backup_code(
            backup_code="ABCD-EFGH-IJKL",
            email="user@example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            login = await response.parse()
            assert login is None

        assert cast(Any, response.is_closed) is True
