# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestComponent:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_retrieve(self, client: StudyfetchSDK) -> None:
        component = client.v1.embed.component.retrieve(
            component_id="componentId",
            token="token",
        )
        assert component is None

    @parametrize
    def test_raw_response_retrieve(self, client: StudyfetchSDK) -> None:
        response = client.v1.embed.component.with_raw_response.retrieve(
            component_id="componentId",
            token="token",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        component = response.parse()
        assert component is None

    @parametrize
    def test_streaming_response_retrieve(self, client: StudyfetchSDK) -> None:
        with client.v1.embed.component.with_streaming_response.retrieve(
            component_id="componentId",
            token="token",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            component = response.parse()
            assert component is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `component_id` but received ''"):
            client.v1.embed.component.with_raw_response.retrieve(
                component_id="",
                token="token",
            )

    @parametrize
    def test_method_interact(self, client: StudyfetchSDK) -> None:
        component = client.v1.embed.component.interact(
            component_id="componentId",
            token="token",
            body="body",
        )
        assert component is None

    @parametrize
    def test_raw_response_interact(self, client: StudyfetchSDK) -> None:
        response = client.v1.embed.component.with_raw_response.interact(
            component_id="componentId",
            token="token",
            body="body",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        component = response.parse()
        assert component is None

    @parametrize
    def test_streaming_response_interact(self, client: StudyfetchSDK) -> None:
        with client.v1.embed.component.with_streaming_response.interact(
            component_id="componentId",
            token="token",
            body="body",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            component = response.parse()
            assert component is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_interact(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `component_id` but received ''"):
            client.v1.embed.component.with_raw_response.interact(
                component_id="",
                token="token",
                body="body",
            )


class TestAsyncComponent:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        component = await async_client.v1.embed.component.retrieve(
            component_id="componentId",
            token="token",
        )
        assert component is None

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.embed.component.with_raw_response.retrieve(
            component_id="componentId",
            token="token",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        component = await response.parse()
        assert component is None

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.embed.component.with_streaming_response.retrieve(
            component_id="componentId",
            token="token",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            component = await response.parse()
            assert component is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `component_id` but received ''"):
            await async_client.v1.embed.component.with_raw_response.retrieve(
                component_id="",
                token="token",
            )

    @parametrize
    async def test_method_interact(self, async_client: AsyncStudyfetchSDK) -> None:
        component = await async_client.v1.embed.component.interact(
            component_id="componentId",
            token="token",
            body="body",
        )
        assert component is None

    @parametrize
    async def test_raw_response_interact(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.embed.component.with_raw_response.interact(
            component_id="componentId",
            token="token",
            body="body",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        component = await response.parse()
        assert component is None

    @parametrize
    async def test_streaming_response_interact(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.embed.component.with_streaming_response.interact(
            component_id="componentId",
            token="token",
            body="body",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            component = await response.parse()
            assert component is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_interact(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `component_id` but received ''"):
            await async_client.v1.embed.component.with_raw_response.interact(
                component_id="",
                token="token",
                body="body",
            )
