# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK
from studyfetch_sdk.types.v1.materials import (
    UploadUploadFileResponse,
    UploadUploadFromURLResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestUpload:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_complete_upload(self, client: StudyfetchSDK) -> None:
        upload = client.v1.materials.upload.complete_upload()
        assert upload is None

    @parametrize
    def test_raw_response_complete_upload(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.upload.with_raw_response.complete_upload()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = response.parse()
        assert upload is None

    @parametrize
    def test_streaming_response_complete_upload(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.upload.with_streaming_response.complete_upload() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = response.parse()
            assert upload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_get_presigned_url(self, client: StudyfetchSDK) -> None:
        upload = client.v1.materials.upload.get_presigned_url()
        assert upload is None

    @parametrize
    def test_raw_response_get_presigned_url(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.upload.with_raw_response.get_presigned_url()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = response.parse()
        assert upload is None

    @parametrize
    def test_streaming_response_get_presigned_url(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.upload.with_streaming_response.get_presigned_url() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = response.parse()
            assert upload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_upload_file(self, client: StudyfetchSDK) -> None:
        upload = client.v1.materials.upload.upload_file(
            file=b"raw file contents",
            name="name",
        )
        assert_matches_type(UploadUploadFileResponse, upload, path=["response"])

    @parametrize
    def test_method_upload_file_with_all_params(self, client: StudyfetchSDK) -> None:
        upload = client.v1.materials.upload.upload_file(
            file=b"raw file contents",
            name="name",
            folder_id="folderId",
        )
        assert_matches_type(UploadUploadFileResponse, upload, path=["response"])

    @parametrize
    def test_raw_response_upload_file(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.upload.with_raw_response.upload_file(
            file=b"raw file contents",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = response.parse()
        assert_matches_type(UploadUploadFileResponse, upload, path=["response"])

    @parametrize
    def test_streaming_response_upload_file(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.upload.with_streaming_response.upload_file(
            file=b"raw file contents",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = response.parse()
            assert_matches_type(UploadUploadFileResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_upload_from_url(self, client: StudyfetchSDK) -> None:
        upload = client.v1.materials.upload.upload_from_url(
            name="name",
            url="url",
        )
        assert_matches_type(UploadUploadFromURLResponse, upload, path=["response"])

    @parametrize
    def test_method_upload_from_url_with_all_params(self, client: StudyfetchSDK) -> None:
        upload = client.v1.materials.upload.upload_from_url(
            name="name",
            url="url",
            folder_id="folderId",
        )
        assert_matches_type(UploadUploadFromURLResponse, upload, path=["response"])

    @parametrize
    def test_raw_response_upload_from_url(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.upload.with_raw_response.upload_from_url(
            name="name",
            url="url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = response.parse()
        assert_matches_type(UploadUploadFromURLResponse, upload, path=["response"])

    @parametrize
    def test_streaming_response_upload_from_url(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.upload.with_streaming_response.upload_from_url(
            name="name",
            url="url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = response.parse()
            assert_matches_type(UploadUploadFromURLResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncUpload:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_complete_upload(self, async_client: AsyncStudyfetchSDK) -> None:
        upload = await async_client.v1.materials.upload.complete_upload()
        assert upload is None

    @parametrize
    async def test_raw_response_complete_upload(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.upload.with_raw_response.complete_upload()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = await response.parse()
        assert upload is None

    @parametrize
    async def test_streaming_response_complete_upload(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.upload.with_streaming_response.complete_upload() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = await response.parse()
            assert upload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_get_presigned_url(self, async_client: AsyncStudyfetchSDK) -> None:
        upload = await async_client.v1.materials.upload.get_presigned_url()
        assert upload is None

    @parametrize
    async def test_raw_response_get_presigned_url(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.upload.with_raw_response.get_presigned_url()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = await response.parse()
        assert upload is None

    @parametrize
    async def test_streaming_response_get_presigned_url(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.upload.with_streaming_response.get_presigned_url() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = await response.parse()
            assert upload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_upload_file(self, async_client: AsyncStudyfetchSDK) -> None:
        upload = await async_client.v1.materials.upload.upload_file(
            file=b"raw file contents",
            name="name",
        )
        assert_matches_type(UploadUploadFileResponse, upload, path=["response"])

    @parametrize
    async def test_method_upload_file_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        upload = await async_client.v1.materials.upload.upload_file(
            file=b"raw file contents",
            name="name",
            folder_id="folderId",
        )
        assert_matches_type(UploadUploadFileResponse, upload, path=["response"])

    @parametrize
    async def test_raw_response_upload_file(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.upload.with_raw_response.upload_file(
            file=b"raw file contents",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = await response.parse()
        assert_matches_type(UploadUploadFileResponse, upload, path=["response"])

    @parametrize
    async def test_streaming_response_upload_file(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.upload.with_streaming_response.upload_file(
            file=b"raw file contents",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = await response.parse()
            assert_matches_type(UploadUploadFileResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_upload_from_url(self, async_client: AsyncStudyfetchSDK) -> None:
        upload = await async_client.v1.materials.upload.upload_from_url(
            name="name",
            url="url",
        )
        assert_matches_type(UploadUploadFromURLResponse, upload, path=["response"])

    @parametrize
    async def test_method_upload_from_url_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        upload = await async_client.v1.materials.upload.upload_from_url(
            name="name",
            url="url",
            folder_id="folderId",
        )
        assert_matches_type(UploadUploadFromURLResponse, upload, path=["response"])

    @parametrize
    async def test_raw_response_upload_from_url(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.upload.with_raw_response.upload_from_url(
            name="name",
            url="url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = await response.parse()
        assert_matches_type(UploadUploadFromURLResponse, upload, path=["response"])

    @parametrize
    async def test_streaming_response_upload_from_url(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.upload.with_streaming_response.upload_from_url(
            name="name",
            url="url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = await response.parse()
            assert_matches_type(UploadUploadFromURLResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True
