# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTeam:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_list(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.profile.team.list()
        assert team is None

    @parametrize
    def test_raw_response_list(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.profile.team.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_list(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.profile.team.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.profile.team.delete(
            "email",
        )
        assert team is None

    @parametrize
    def test_raw_response_delete(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.profile.team.with_raw_response.delete(
            "email",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_delete(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.profile.team.with_streaming_response.delete(
            "email",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            client.v1.organizations.profile.team.with_raw_response.delete(
                "",
            )

    @parametrize
    def test_method_invite(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.profile.team.invite()
        assert team is None

    @parametrize
    def test_raw_response_invite(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.profile.team.with_raw_response.invite()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_invite(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.profile.team.with_streaming_response.invite() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_resend_invite(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.profile.team.resend_invite(
            "email",
        )
        assert team is None

    @parametrize
    def test_raw_response_resend_invite(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.profile.team.with_raw_response.resend_invite(
            "email",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_resend_invite(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.profile.team.with_streaming_response.resend_invite(
            "email",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_resend_invite(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            client.v1.organizations.profile.team.with_raw_response.resend_invite(
                "",
            )

    @parametrize
    def test_method_retrieve_detailed(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.profile.team.retrieve_detailed()
        assert team is None

    @parametrize
    def test_raw_response_retrieve_detailed(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.profile.team.with_raw_response.retrieve_detailed()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_retrieve_detailed(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.profile.team.with_streaming_response.retrieve_detailed() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_update_role(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.profile.team.update_role(
            "email",
        )
        assert team is None

    @parametrize
    def test_raw_response_update_role(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.profile.team.with_raw_response.update_role(
            "email",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_update_role(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.profile.team.with_streaming_response.update_role(
            "email",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update_role(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            client.v1.organizations.profile.team.with_raw_response.update_role(
                "",
            )


class TestAsyncTeam:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_list(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.profile.team.list()
        assert team is None

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.profile.team.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.profile.team.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.profile.team.delete(
            "email",
        )
        assert team is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.profile.team.with_raw_response.delete(
            "email",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.profile.team.with_streaming_response.delete(
            "email",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            await async_client.v1.organizations.profile.team.with_raw_response.delete(
                "",
            )

    @parametrize
    async def test_method_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.profile.team.invite()
        assert team is None

    @parametrize
    async def test_raw_response_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.profile.team.with_raw_response.invite()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.profile.team.with_streaming_response.invite() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_resend_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.profile.team.resend_invite(
            "email",
        )
        assert team is None

    @parametrize
    async def test_raw_response_resend_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.profile.team.with_raw_response.resend_invite(
            "email",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_resend_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.profile.team.with_streaming_response.resend_invite(
            "email",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_resend_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            await async_client.v1.organizations.profile.team.with_raw_response.resend_invite(
                "",
            )

    @parametrize
    async def test_method_retrieve_detailed(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.profile.team.retrieve_detailed()
        assert team is None

    @parametrize
    async def test_raw_response_retrieve_detailed(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.profile.team.with_raw_response.retrieve_detailed()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_retrieve_detailed(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.profile.team.with_streaming_response.retrieve_detailed() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_update_role(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.profile.team.update_role(
            "email",
        )
        assert team is None

    @parametrize
    async def test_raw_response_update_role(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.profile.team.with_raw_response.update_role(
            "email",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_update_role(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.profile.team.with_streaming_response.update_role(
            "email",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update_role(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            await async_client.v1.organizations.profile.team.with_raw_response.update_role(
                "",
            )
