# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestInvite:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: StudyfetchSDK) -> None:
        invite = client.v1.organizations.team.invite.create(
            "id",
        )
        assert invite is None

    @parametrize
    def test_raw_response_create(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.team.invite.with_raw_response.create(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        invite = response.parse()
        assert invite is None

    @parametrize
    def test_streaming_response_create(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.team.invite.with_streaming_response.create(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            invite = response.parse()
            assert invite is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.organizations.team.invite.with_raw_response.create(
                "",
            )

    @parametrize
    def test_method_retrieve_preview(self, client: StudyfetchSDK) -> None:
        invite = client.v1.organizations.team.invite.retrieve_preview(
            "token",
        )
        assert invite is None

    @parametrize
    def test_raw_response_retrieve_preview(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.team.invite.with_raw_response.retrieve_preview(
            "token",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        invite = response.parse()
        assert invite is None

    @parametrize
    def test_streaming_response_retrieve_preview(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.team.invite.with_streaming_response.retrieve_preview(
            "token",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            invite = response.parse()
            assert invite is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve_preview(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `token` but received ''"):
            client.v1.organizations.team.invite.with_raw_response.retrieve_preview(
                "",
            )


class TestAsyncInvite:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncStudyfetchSDK) -> None:
        invite = await async_client.v1.organizations.team.invite.create(
            "id",
        )
        assert invite is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.team.invite.with_raw_response.create(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        invite = await response.parse()
        assert invite is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.team.invite.with_streaming_response.create(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            invite = await response.parse()
            assert invite is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.organizations.team.invite.with_raw_response.create(
                "",
            )

    @parametrize
    async def test_method_retrieve_preview(self, async_client: AsyncStudyfetchSDK) -> None:
        invite = await async_client.v1.organizations.team.invite.retrieve_preview(
            "token",
        )
        assert invite is None

    @parametrize
    async def test_raw_response_retrieve_preview(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.team.invite.with_raw_response.retrieve_preview(
            "token",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        invite = await response.parse()
        assert invite is None

    @parametrize
    async def test_streaming_response_retrieve_preview(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.team.invite.with_streaming_response.retrieve_preview(
            "token",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            invite = await response.parse()
            assert invite is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve_preview(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `token` but received ''"):
            await async_client.v1.organizations.team.invite.with_raw_response.retrieve_preview(
                "",
            )
