# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTeam:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_list(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.team.list(
            "id",
        )
        assert team is None

    @parametrize
    def test_raw_response_list(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.team.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_list(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.team.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.organizations.team.with_raw_response.list(
                "",
            )

    @parametrize
    def test_method_delete(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.team.delete(
            email="email",
            id="id",
        )
        assert team is None

    @parametrize
    def test_raw_response_delete(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.team.with_raw_response.delete(
            email="email",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_delete(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.team.with_streaming_response.delete(
            email="email",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.organizations.team.with_raw_response.delete(
                email="email",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            client.v1.organizations.team.with_raw_response.delete(
                email="",
                id="id",
            )

    @parametrize
    def test_method_accept_invite(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.team.accept_invite()
        assert team is None

    @parametrize
    def test_raw_response_accept_invite(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.team.with_raw_response.accept_invite()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_accept_invite(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.team.with_streaming_response.accept_invite() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_resend_invite(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.team.resend_invite(
            email="email",
            id="id",
        )
        assert team is None

    @parametrize
    def test_raw_response_resend_invite(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.team.with_raw_response.resend_invite(
            email="email",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_resend_invite(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.team.with_streaming_response.resend_invite(
            email="email",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_resend_invite(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.organizations.team.with_raw_response.resend_invite(
                email="email",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            client.v1.organizations.team.with_raw_response.resend_invite(
                email="",
                id="id",
            )

    @parametrize
    def test_method_retrieve_detailed(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.team.retrieve_detailed(
            "id",
        )
        assert team is None

    @parametrize
    def test_raw_response_retrieve_detailed(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.team.with_raw_response.retrieve_detailed(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_retrieve_detailed(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.team.with_streaming_response.retrieve_detailed(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve_detailed(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.organizations.team.with_raw_response.retrieve_detailed(
                "",
            )

    @parametrize
    def test_method_update_role(self, client: StudyfetchSDK) -> None:
        team = client.v1.organizations.team.update_role(
            email="email",
            id="id",
        )
        assert team is None

    @parametrize
    def test_raw_response_update_role(self, client: StudyfetchSDK) -> None:
        response = client.v1.organizations.team.with_raw_response.update_role(
            email="email",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert team is None

    @parametrize
    def test_streaming_response_update_role(self, client: StudyfetchSDK) -> None:
        with client.v1.organizations.team.with_streaming_response.update_role(
            email="email",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update_role(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.organizations.team.with_raw_response.update_role(
                email="email",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            client.v1.organizations.team.with_raw_response.update_role(
                email="",
                id="id",
            )


class TestAsyncTeam:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_list(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.team.list(
            "id",
        )
        assert team is None

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.team.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.team.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.organizations.team.with_raw_response.list(
                "",
            )

    @parametrize
    async def test_method_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.team.delete(
            email="email",
            id="id",
        )
        assert team is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.team.with_raw_response.delete(
            email="email",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.team.with_streaming_response.delete(
            email="email",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.organizations.team.with_raw_response.delete(
                email="email",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            await async_client.v1.organizations.team.with_raw_response.delete(
                email="",
                id="id",
            )

    @parametrize
    async def test_method_accept_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.team.accept_invite()
        assert team is None

    @parametrize
    async def test_raw_response_accept_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.team.with_raw_response.accept_invite()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_accept_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.team.with_streaming_response.accept_invite() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_resend_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.team.resend_invite(
            email="email",
            id="id",
        )
        assert team is None

    @parametrize
    async def test_raw_response_resend_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.team.with_raw_response.resend_invite(
            email="email",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_resend_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.team.with_streaming_response.resend_invite(
            email="email",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_resend_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.organizations.team.with_raw_response.resend_invite(
                email="email",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            await async_client.v1.organizations.team.with_raw_response.resend_invite(
                email="",
                id="id",
            )

    @parametrize
    async def test_method_retrieve_detailed(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.team.retrieve_detailed(
            "id",
        )
        assert team is None

    @parametrize
    async def test_raw_response_retrieve_detailed(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.team.with_raw_response.retrieve_detailed(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_retrieve_detailed(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.team.with_streaming_response.retrieve_detailed(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve_detailed(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.organizations.team.with_raw_response.retrieve_detailed(
                "",
            )

    @parametrize
    async def test_method_update_role(self, async_client: AsyncStudyfetchSDK) -> None:
        team = await async_client.v1.organizations.team.update_role(
            email="email",
            id="id",
        )
        assert team is None

    @parametrize
    async def test_raw_response_update_role(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.organizations.team.with_raw_response.update_role(
            email="email",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert team is None

    @parametrize
    async def test_streaming_response_update_role(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.organizations.team.with_streaming_response.update_role(
            email="email",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert team is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update_role(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.organizations.team.with_raw_response.update_role(
                email="email",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `email` but received ''"):
            await async_client.v1.organizations.team.with_raw_response.update_role(
                email="",
                id="id",
            )
