# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAuth:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_get_profile(self, client: StudyfetchSDK) -> None:
        auth = client.v1.auth.get_profile()
        assert auth is None

    @parametrize
    def test_raw_response_get_profile(self, client: StudyfetchSDK) -> None:
        response = client.v1.auth.with_raw_response.get_profile()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = response.parse()
        assert auth is None

    @parametrize
    def test_streaming_response_get_profile(self, client: StudyfetchSDK) -> None:
        with client.v1.auth.with_streaming_response.get_profile() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_register_new_user(self, client: StudyfetchSDK) -> None:
        auth = client.v1.auth.register_new_user(
            email="user@example.com",
            name="John Doe",
            organization_name="Acme Corp",
            password="password123",
        )
        assert auth is None

    @parametrize
    def test_raw_response_register_new_user(self, client: StudyfetchSDK) -> None:
        response = client.v1.auth.with_raw_response.register_new_user(
            email="user@example.com",
            name="John Doe",
            organization_name="Acme Corp",
            password="password123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = response.parse()
        assert auth is None

    @parametrize
    def test_streaming_response_register_new_user(self, client: StudyfetchSDK) -> None:
        with client.v1.auth.with_streaming_response.register_new_user(
            email="user@example.com",
            name="John Doe",
            organization_name="Acme Corp",
            password="password123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_register_organization(self, client: StudyfetchSDK) -> None:
        auth = client.v1.auth.register_organization()
        assert auth is None

    @parametrize
    def test_raw_response_register_organization(self, client: StudyfetchSDK) -> None:
        response = client.v1.auth.with_raw_response.register_organization()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = response.parse()
        assert auth is None

    @parametrize
    def test_streaming_response_register_organization(self, client: StudyfetchSDK) -> None:
        with client.v1.auth.with_streaming_response.register_organization() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_register_with_invite(self, client: StudyfetchSDK) -> None:
        auth = client.v1.auth.register_with_invite()
        assert auth is None

    @parametrize
    def test_raw_response_register_with_invite(self, client: StudyfetchSDK) -> None:
        response = client.v1.auth.with_raw_response.register_with_invite()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = response.parse()
        assert auth is None

    @parametrize
    def test_streaming_response_register_with_invite(self, client: StudyfetchSDK) -> None:
        with client.v1.auth.with_streaming_response.register_with_invite() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_request_password_reset(self, client: StudyfetchSDK) -> None:
        auth = client.v1.auth.request_password_reset(
            email="user@example.com",
        )
        assert auth is None

    @parametrize
    def test_raw_response_request_password_reset(self, client: StudyfetchSDK) -> None:
        response = client.v1.auth.with_raw_response.request_password_reset(
            email="user@example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = response.parse()
        assert auth is None

    @parametrize
    def test_streaming_response_request_password_reset(self, client: StudyfetchSDK) -> None:
        with client.v1.auth.with_streaming_response.request_password_reset(
            email="user@example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_reset_password(self, client: StudyfetchSDK) -> None:
        auth = client.v1.auth.reset_password(
            token="reset-token-uuid",
            new_password="newPassword123",
        )
        assert auth is None

    @parametrize
    def test_raw_response_reset_password(self, client: StudyfetchSDK) -> None:
        response = client.v1.auth.with_raw_response.reset_password(
            token="reset-token-uuid",
            new_password="newPassword123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = response.parse()
        assert auth is None

    @parametrize
    def test_streaming_response_reset_password(self, client: StudyfetchSDK) -> None:
        with client.v1.auth.with_streaming_response.reset_password(
            token="reset-token-uuid",
            new_password="newPassword123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True


class TestAsyncAuth:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_get_profile(self, async_client: AsyncStudyfetchSDK) -> None:
        auth = await async_client.v1.auth.get_profile()
        assert auth is None

    @parametrize
    async def test_raw_response_get_profile(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.auth.with_raw_response.get_profile()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = await response.parse()
        assert auth is None

    @parametrize
    async def test_streaming_response_get_profile(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.auth.with_streaming_response.get_profile() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = await response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_register_new_user(self, async_client: AsyncStudyfetchSDK) -> None:
        auth = await async_client.v1.auth.register_new_user(
            email="user@example.com",
            name="John Doe",
            organization_name="Acme Corp",
            password="password123",
        )
        assert auth is None

    @parametrize
    async def test_raw_response_register_new_user(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.auth.with_raw_response.register_new_user(
            email="user@example.com",
            name="John Doe",
            organization_name="Acme Corp",
            password="password123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = await response.parse()
        assert auth is None

    @parametrize
    async def test_streaming_response_register_new_user(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.auth.with_streaming_response.register_new_user(
            email="user@example.com",
            name="John Doe",
            organization_name="Acme Corp",
            password="password123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = await response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_register_organization(self, async_client: AsyncStudyfetchSDK) -> None:
        auth = await async_client.v1.auth.register_organization()
        assert auth is None

    @parametrize
    async def test_raw_response_register_organization(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.auth.with_raw_response.register_organization()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = await response.parse()
        assert auth is None

    @parametrize
    async def test_streaming_response_register_organization(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.auth.with_streaming_response.register_organization() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = await response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_register_with_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        auth = await async_client.v1.auth.register_with_invite()
        assert auth is None

    @parametrize
    async def test_raw_response_register_with_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.auth.with_raw_response.register_with_invite()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = await response.parse()
        assert auth is None

    @parametrize
    async def test_streaming_response_register_with_invite(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.auth.with_streaming_response.register_with_invite() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = await response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_request_password_reset(self, async_client: AsyncStudyfetchSDK) -> None:
        auth = await async_client.v1.auth.request_password_reset(
            email="user@example.com",
        )
        assert auth is None

    @parametrize
    async def test_raw_response_request_password_reset(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.auth.with_raw_response.request_password_reset(
            email="user@example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = await response.parse()
        assert auth is None

    @parametrize
    async def test_streaming_response_request_password_reset(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.auth.with_streaming_response.request_password_reset(
            email="user@example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = await response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_reset_password(self, async_client: AsyncStudyfetchSDK) -> None:
        auth = await async_client.v1.auth.reset_password(
            token="reset-token-uuid",
            new_password="newPassword123",
        )
        assert auth is None

    @parametrize
    async def test_raw_response_reset_password(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.auth.with_raw_response.reset_password(
            token="reset-token-uuid",
            new_password="newPassword123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        auth = await response.parse()
        assert auth is None

    @parametrize
    async def test_streaming_response_reset_password(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.auth.with_streaming_response.reset_password(
            token="reset-token-uuid",
            new_password="newPassword123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            auth = await response.parse()
            assert auth is None

        assert cast(Any, response.is_closed) is True
