# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestChat:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_get_history(self, client: StudyfetchSDK) -> None:
        chat = client.v1.chat.get_history()
        assert chat is None

    @parametrize
    def test_raw_response_get_history(self, client: StudyfetchSDK) -> None:
        response = client.v1.chat.with_raw_response.get_history()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = response.parse()
        assert chat is None

    @parametrize
    def test_streaming_response_get_history(self, client: StudyfetchSDK) -> None:
        with client.v1.chat.with_streaming_response.get_history() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = response.parse()
            assert chat is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve_session(self, client: StudyfetchSDK) -> None:
        chat = client.v1.chat.retrieve_session(
            session_id="sessionId",
            user_id="userId",
        )
        assert chat is None

    @parametrize
    def test_raw_response_retrieve_session(self, client: StudyfetchSDK) -> None:
        response = client.v1.chat.with_raw_response.retrieve_session(
            session_id="sessionId",
            user_id="userId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = response.parse()
        assert chat is None

    @parametrize
    def test_streaming_response_retrieve_session(self, client: StudyfetchSDK) -> None:
        with client.v1.chat.with_streaming_response.retrieve_session(
            session_id="sessionId",
            user_id="userId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = response.parse()
            assert chat is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve_session(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `session_id` but received ''"):
            client.v1.chat.with_raw_response.retrieve_session(
                session_id="",
                user_id="userId",
            )

    @parametrize
    def test_method_send_followups(self, client: StudyfetchSDK) -> None:
        chat = client.v1.chat.send_followups()
        assert chat is None

    @parametrize
    def test_raw_response_send_followups(self, client: StudyfetchSDK) -> None:
        response = client.v1.chat.with_raw_response.send_followups()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = response.parse()
        assert chat is None

    @parametrize
    def test_streaming_response_send_followups(self, client: StudyfetchSDK) -> None:
        with client.v1.chat.with_streaming_response.send_followups() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = response.parse()
            assert chat is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_send_message(self, client: StudyfetchSDK) -> None:
        chat = client.v1.chat.send_message(
            component_id="componentId",
            message={},
            x_component_id="x-component-id",
        )
        assert chat is None

    @parametrize
    def test_method_send_message_with_all_params(self, client: StudyfetchSDK) -> None:
        chat = client.v1.chat.send_message(
            component_id="componentId",
            message={
                "images": [
                    {
                        "base64": "base64",
                        "caption": "caption",
                        "mime_type": "mimeType",
                        "url": "url",
                    }
                ],
                "text": "text",
            },
            x_component_id="x-component-id",
            context={},
            group_id="groupId",
            session_id="sessionId",
            user_id="userId",
        )
        assert chat is None

    @parametrize
    def test_raw_response_send_message(self, client: StudyfetchSDK) -> None:
        response = client.v1.chat.with_raw_response.send_message(
            component_id="componentId",
            message={},
            x_component_id="x-component-id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = response.parse()
        assert chat is None

    @parametrize
    def test_streaming_response_send_message(self, client: StudyfetchSDK) -> None:
        with client.v1.chat.with_streaming_response.send_message(
            component_id="componentId",
            message={},
            x_component_id="x-component-id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = response.parse()
            assert chat is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_stream(self, client: StudyfetchSDK) -> None:
        chat = client.v1.chat.stream()
        assert chat is None

    @parametrize
    def test_method_stream_with_all_params(self, client: StudyfetchSDK) -> None:
        chat = client.v1.chat.stream(
            context={},
            group_id="groupId",
            messages=[
                {
                    "content": "content",
                    "role": "user",
                }
            ],
            user_id="userId",
            x_component_id="x-component-id",
        )
        assert chat is None

    @parametrize
    def test_raw_response_stream(self, client: StudyfetchSDK) -> None:
        response = client.v1.chat.with_raw_response.stream()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = response.parse()
        assert chat is None

    @parametrize
    def test_streaming_response_stream(self, client: StudyfetchSDK) -> None:
        with client.v1.chat.with_streaming_response.stream() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = response.parse()
            assert chat is None

        assert cast(Any, response.is_closed) is True


class TestAsyncChat:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_get_history(self, async_client: AsyncStudyfetchSDK) -> None:
        chat = await async_client.v1.chat.get_history()
        assert chat is None

    @parametrize
    async def test_raw_response_get_history(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.chat.with_raw_response.get_history()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = await response.parse()
        assert chat is None

    @parametrize
    async def test_streaming_response_get_history(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.chat.with_streaming_response.get_history() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = await response.parse()
            assert chat is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve_session(self, async_client: AsyncStudyfetchSDK) -> None:
        chat = await async_client.v1.chat.retrieve_session(
            session_id="sessionId",
            user_id="userId",
        )
        assert chat is None

    @parametrize
    async def test_raw_response_retrieve_session(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.chat.with_raw_response.retrieve_session(
            session_id="sessionId",
            user_id="userId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = await response.parse()
        assert chat is None

    @parametrize
    async def test_streaming_response_retrieve_session(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.chat.with_streaming_response.retrieve_session(
            session_id="sessionId",
            user_id="userId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = await response.parse()
            assert chat is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve_session(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `session_id` but received ''"):
            await async_client.v1.chat.with_raw_response.retrieve_session(
                session_id="",
                user_id="userId",
            )

    @parametrize
    async def test_method_send_followups(self, async_client: AsyncStudyfetchSDK) -> None:
        chat = await async_client.v1.chat.send_followups()
        assert chat is None

    @parametrize
    async def test_raw_response_send_followups(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.chat.with_raw_response.send_followups()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = await response.parse()
        assert chat is None

    @parametrize
    async def test_streaming_response_send_followups(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.chat.with_streaming_response.send_followups() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = await response.parse()
            assert chat is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_send_message(self, async_client: AsyncStudyfetchSDK) -> None:
        chat = await async_client.v1.chat.send_message(
            component_id="componentId",
            message={},
            x_component_id="x-component-id",
        )
        assert chat is None

    @parametrize
    async def test_method_send_message_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        chat = await async_client.v1.chat.send_message(
            component_id="componentId",
            message={
                "images": [
                    {
                        "base64": "base64",
                        "caption": "caption",
                        "mime_type": "mimeType",
                        "url": "url",
                    }
                ],
                "text": "text",
            },
            x_component_id="x-component-id",
            context={},
            group_id="groupId",
            session_id="sessionId",
            user_id="userId",
        )
        assert chat is None

    @parametrize
    async def test_raw_response_send_message(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.chat.with_raw_response.send_message(
            component_id="componentId",
            message={},
            x_component_id="x-component-id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = await response.parse()
        assert chat is None

    @parametrize
    async def test_streaming_response_send_message(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.chat.with_streaming_response.send_message(
            component_id="componentId",
            message={},
            x_component_id="x-component-id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = await response.parse()
            assert chat is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_stream(self, async_client: AsyncStudyfetchSDK) -> None:
        chat = await async_client.v1.chat.stream()
        assert chat is None

    @parametrize
    async def test_method_stream_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        chat = await async_client.v1.chat.stream(
            context={},
            group_id="groupId",
            messages=[
                {
                    "content": "content",
                    "role": "user",
                }
            ],
            user_id="userId",
            x_component_id="x-component-id",
        )
        assert chat is None

    @parametrize
    async def test_raw_response_stream(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.chat.with_raw_response.stream()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = await response.parse()
        assert chat is None

    @parametrize
    async def test_streaming_response_stream(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.chat.with_streaming_response.stream() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = await response.parse()
            assert chat is None

        assert cast(Any, response.is_closed) is True
