# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestExplainers:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: StudyfetchSDK) -> None:
        explainer = client.v1.explainers.create()
        assert explainer is None

    @parametrize
    def test_raw_response_create(self, client: StudyfetchSDK) -> None:
        response = client.v1.explainers.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        explainer = response.parse()
        assert explainer is None

    @parametrize
    def test_streaming_response_create(self, client: StudyfetchSDK) -> None:
        with client.v1.explainers.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            explainer = response.parse()
            assert explainer is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_handle_webhook(self, client: StudyfetchSDK) -> None:
        explainer = client.v1.explainers.handle_webhook(
            body="body",
        )
        assert explainer is None

    @parametrize
    def test_raw_response_handle_webhook(self, client: StudyfetchSDK) -> None:
        response = client.v1.explainers.with_raw_response.handle_webhook(
            body="body",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        explainer = response.parse()
        assert explainer is None

    @parametrize
    def test_streaming_response_handle_webhook(self, client: StudyfetchSDK) -> None:
        with client.v1.explainers.with_streaming_response.handle_webhook(
            body="body",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            explainer = response.parse()
            assert explainer is None

        assert cast(Any, response.is_closed) is True


class TestAsyncExplainers:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncStudyfetchSDK) -> None:
        explainer = await async_client.v1.explainers.create()
        assert explainer is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.explainers.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        explainer = await response.parse()
        assert explainer is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.explainers.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            explainer = await response.parse()
            assert explainer is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_handle_webhook(self, async_client: AsyncStudyfetchSDK) -> None:
        explainer = await async_client.v1.explainers.handle_webhook(
            body="body",
        )
        assert explainer is None

    @parametrize
    async def test_raw_response_handle_webhook(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.explainers.with_raw_response.handle_webhook(
            body="body",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        explainer = await response.parse()
        assert explainer is None

    @parametrize
    async def test_streaming_response_handle_webhook(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.explainers.with_streaming_response.handle_webhook(
            body="body",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            explainer = await response.parse()
            assert explainer is None

        assert cast(Any, response.is_closed) is True
