# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestFolders:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.create(
            name="name",
        )
        assert folder is None

    @parametrize
    def test_method_create_with_all_params(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.create(
            name="name",
            parent_id="parentId",
        )
        assert folder is None

    @parametrize
    def test_raw_response_create(self, client: StudyfetchSDK) -> None:
        response = client.v1.folders.with_raw_response.create(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = response.parse()
        assert folder is None

    @parametrize
    def test_streaming_response_create(self, client: StudyfetchSDK) -> None:
        with client.v1.folders.with_streaming_response.create(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.retrieve(
            "id",
        )
        assert folder is None

    @parametrize
    def test_raw_response_retrieve(self, client: StudyfetchSDK) -> None:
        response = client.v1.folders.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = response.parse()
        assert folder is None

    @parametrize
    def test_streaming_response_retrieve(self, client: StudyfetchSDK) -> None:
        with client.v1.folders.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.folders.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_update(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.update(
            id="id",
        )
        assert folder is None

    @parametrize
    def test_method_update_with_all_params(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.update(
            id="id",
            name="name",
            parent_id="parentId",
        )
        assert folder is None

    @parametrize
    def test_raw_response_update(self, client: StudyfetchSDK) -> None:
        response = client.v1.folders.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = response.parse()
        assert folder is None

    @parametrize
    def test_streaming_response_update(self, client: StudyfetchSDK) -> None:
        with client.v1.folders.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.folders.with_raw_response.update(
                id="",
            )

    @parametrize
    def test_method_list(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.list()
        assert folder is None

    @parametrize
    def test_method_list_with_all_params(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.list(
            parent_id={},
        )
        assert folder is None

    @parametrize
    def test_raw_response_list(self, client: StudyfetchSDK) -> None:
        response = client.v1.folders.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = response.parse()
        assert folder is None

    @parametrize
    def test_streaming_response_list(self, client: StudyfetchSDK) -> None:
        with client.v1.folders.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.delete(
            "id",
        )
        assert folder is None

    @parametrize
    def test_raw_response_delete(self, client: StudyfetchSDK) -> None:
        response = client.v1.folders.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = response.parse()
        assert folder is None

    @parametrize
    def test_streaming_response_delete(self, client: StudyfetchSDK) -> None:
        with client.v1.folders.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.folders.with_raw_response.delete(
                "",
            )

    @parametrize
    def test_method_get_tree(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.get_tree()
        assert folder is None

    @parametrize
    def test_raw_response_get_tree(self, client: StudyfetchSDK) -> None:
        response = client.v1.folders.with_raw_response.get_tree()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = response.parse()
        assert folder is None

    @parametrize
    def test_streaming_response_get_tree(self, client: StudyfetchSDK) -> None:
        with client.v1.folders.with_streaming_response.get_tree() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_list_materials(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.list_materials(
            "id",
        )
        assert folder is None

    @parametrize
    def test_raw_response_list_materials(self, client: StudyfetchSDK) -> None:
        response = client.v1.folders.with_raw_response.list_materials(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = response.parse()
        assert folder is None

    @parametrize
    def test_streaming_response_list_materials(self, client: StudyfetchSDK) -> None:
        with client.v1.folders.with_streaming_response.list_materials(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list_materials(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.folders.with_raw_response.list_materials(
                "",
            )

    @parametrize
    def test_method_move(self, client: StudyfetchSDK) -> None:
        folder = client.v1.folders.move(
            "id",
        )
        assert folder is None

    @parametrize
    def test_raw_response_move(self, client: StudyfetchSDK) -> None:
        response = client.v1.folders.with_raw_response.move(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = response.parse()
        assert folder is None

    @parametrize
    def test_streaming_response_move(self, client: StudyfetchSDK) -> None:
        with client.v1.folders.with_streaming_response.move(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_move(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.folders.with_raw_response.move(
                "",
            )


class TestAsyncFolders:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.create(
            name="name",
        )
        assert folder is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.create(
            name="name",
            parent_id="parentId",
        )
        assert folder is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.folders.with_raw_response.create(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = await response.parse()
        assert folder is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.folders.with_streaming_response.create(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = await response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.retrieve(
            "id",
        )
        assert folder is None

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.folders.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = await response.parse()
        assert folder is None

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.folders.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = await response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.folders.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_update(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.update(
            id="id",
        )
        assert folder is None

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.update(
            id="id",
            name="name",
            parent_id="parentId",
        )
        assert folder is None

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.folders.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = await response.parse()
        assert folder is None

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.folders.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = await response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.folders.with_raw_response.update(
                id="",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.list()
        assert folder is None

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.list(
            parent_id={},
        )
        assert folder is None

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.folders.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = await response.parse()
        assert folder is None

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.folders.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = await response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.delete(
            "id",
        )
        assert folder is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.folders.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = await response.parse()
        assert folder is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.folders.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = await response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.folders.with_raw_response.delete(
                "",
            )

    @parametrize
    async def test_method_get_tree(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.get_tree()
        assert folder is None

    @parametrize
    async def test_raw_response_get_tree(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.folders.with_raw_response.get_tree()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = await response.parse()
        assert folder is None

    @parametrize
    async def test_streaming_response_get_tree(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.folders.with_streaming_response.get_tree() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = await response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_list_materials(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.list_materials(
            "id",
        )
        assert folder is None

    @parametrize
    async def test_raw_response_list_materials(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.folders.with_raw_response.list_materials(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = await response.parse()
        assert folder is None

    @parametrize
    async def test_streaming_response_list_materials(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.folders.with_streaming_response.list_materials(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = await response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list_materials(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.folders.with_raw_response.list_materials(
                "",
            )

    @parametrize
    async def test_method_move(self, async_client: AsyncStudyfetchSDK) -> None:
        folder = await async_client.v1.folders.move(
            "id",
        )
        assert folder is None

    @parametrize
    async def test_raw_response_move(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.folders.with_raw_response.move(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        folder = await response.parse()
        assert folder is None

    @parametrize
    async def test_streaming_response_move(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.folders.with_streaming_response.move(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            folder = await response.parse()
            assert folder is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_move(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.folders.with_raw_response.move(
                "",
            )
