# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK
from studyfetch_sdk.types.v1 import (
    MaterialListResponse,
    MaterialCreateResponse,
    MaterialRetrieveResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMaterials:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.create(
            content={"type": "text"},
            name="Chapter 1 - Introduction",
        )
        assert_matches_type(MaterialCreateResponse, material, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.create(
            content={
                "type": "text",
                "source_url": "sourceUrl",
                "text": "text",
                "url": "url",
            },
            name="Chapter 1 - Introduction",
            folder_id="folderId",
        )
        assert_matches_type(MaterialCreateResponse, material, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.create(
            content={"type": "text"},
            name="Chapter 1 - Introduction",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert_matches_type(MaterialCreateResponse, material, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.create(
            content={"type": "text"},
            name="Chapter 1 - Introduction",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert_matches_type(MaterialCreateResponse, material, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.retrieve(
            "id",
        )
        assert_matches_type(MaterialRetrieveResponse, material, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert_matches_type(MaterialRetrieveResponse, material, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert_matches_type(MaterialRetrieveResponse, material, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.materials.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_list(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.list()
        assert_matches_type(MaterialListResponse, material, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.list(
            folder_id="folderId",
        )
        assert_matches_type(MaterialListResponse, material, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert_matches_type(MaterialListResponse, material, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert_matches_type(MaterialListResponse, material, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.delete(
            "id",
        )
        assert material is None

    @parametrize
    def test_raw_response_delete(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert material is None

    @parametrize
    def test_streaming_response_delete(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.materials.with_raw_response.delete(
                "",
            )

    @parametrize
    def test_method_create_batch(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.create_batch()
        assert material is None

    @parametrize
    def test_raw_response_create_batch(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.create_batch()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert material is None

    @parametrize
    def test_streaming_response_create_batch(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.create_batch() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_debug(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.debug(
            "id",
        )
        assert material is None

    @parametrize
    def test_raw_response_debug(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.debug(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert material is None

    @parametrize
    def test_streaming_response_debug(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.debug(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_debug(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.materials.with_raw_response.debug(
                "",
            )

    @parametrize
    def test_method_get_download_url(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.get_download_url(
            id="id",
            expires_in="expiresIn",
        )
        assert material is None

    @parametrize
    def test_raw_response_get_download_url(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.get_download_url(
            id="id",
            expires_in="expiresIn",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert material is None

    @parametrize
    def test_streaming_response_get_download_url(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.get_download_url(
            id="id",
            expires_in="expiresIn",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_download_url(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.materials.with_raw_response.get_download_url(
                id="",
                expires_in="expiresIn",
            )

    @parametrize
    def test_method_move(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.move(
            "id",
        )
        assert material is None

    @parametrize
    def test_raw_response_move(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.move(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert material is None

    @parametrize
    def test_streaming_response_move(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.move(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_move(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.materials.with_raw_response.move(
                "",
            )

    @parametrize
    def test_method_rename(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.rename(
            "id",
        )
        assert material is None

    @parametrize
    def test_raw_response_rename(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.rename(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert material is None

    @parametrize
    def test_streaming_response_rename(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.rename(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_rename(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.materials.with_raw_response.rename(
                "",
            )

    @parametrize
    def test_method_reprocess(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.reprocess(
            "id",
        )
        assert material is None

    @parametrize
    def test_raw_response_reprocess(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.reprocess(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert material is None

    @parametrize
    def test_streaming_response_reprocess(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.reprocess(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_reprocess(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.materials.with_raw_response.reprocess(
                "",
            )

    @parametrize
    def test_method_search(self, client: StudyfetchSDK) -> None:
        material = client.v1.materials.search()
        assert material is None

    @parametrize
    def test_raw_response_search(self, client: StudyfetchSDK) -> None:
        response = client.v1.materials.with_raw_response.search()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = response.parse()
        assert material is None

    @parametrize
    def test_streaming_response_search(self, client: StudyfetchSDK) -> None:
        with client.v1.materials.with_streaming_response.search() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True


class TestAsyncMaterials:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.create(
            content={"type": "text"},
            name="Chapter 1 - Introduction",
        )
        assert_matches_type(MaterialCreateResponse, material, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.create(
            content={
                "type": "text",
                "source_url": "sourceUrl",
                "text": "text",
                "url": "url",
            },
            name="Chapter 1 - Introduction",
            folder_id="folderId",
        )
        assert_matches_type(MaterialCreateResponse, material, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.create(
            content={"type": "text"},
            name="Chapter 1 - Introduction",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert_matches_type(MaterialCreateResponse, material, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.create(
            content={"type": "text"},
            name="Chapter 1 - Introduction",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert_matches_type(MaterialCreateResponse, material, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.retrieve(
            "id",
        )
        assert_matches_type(MaterialRetrieveResponse, material, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert_matches_type(MaterialRetrieveResponse, material, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert_matches_type(MaterialRetrieveResponse, material, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.materials.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.list()
        assert_matches_type(MaterialListResponse, material, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.list(
            folder_id="folderId",
        )
        assert_matches_type(MaterialListResponse, material, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert_matches_type(MaterialListResponse, material, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert_matches_type(MaterialListResponse, material, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.delete(
            "id",
        )
        assert material is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert material is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.materials.with_raw_response.delete(
                "",
            )

    @parametrize
    async def test_method_create_batch(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.create_batch()
        assert material is None

    @parametrize
    async def test_raw_response_create_batch(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.create_batch()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert material is None

    @parametrize
    async def test_streaming_response_create_batch(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.create_batch() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_debug(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.debug(
            "id",
        )
        assert material is None

    @parametrize
    async def test_raw_response_debug(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.debug(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert material is None

    @parametrize
    async def test_streaming_response_debug(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.debug(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_debug(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.materials.with_raw_response.debug(
                "",
            )

    @parametrize
    async def test_method_get_download_url(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.get_download_url(
            id="id",
            expires_in="expiresIn",
        )
        assert material is None

    @parametrize
    async def test_raw_response_get_download_url(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.get_download_url(
            id="id",
            expires_in="expiresIn",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert material is None

    @parametrize
    async def test_streaming_response_get_download_url(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.get_download_url(
            id="id",
            expires_in="expiresIn",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_download_url(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.materials.with_raw_response.get_download_url(
                id="",
                expires_in="expiresIn",
            )

    @parametrize
    async def test_method_move(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.move(
            "id",
        )
        assert material is None

    @parametrize
    async def test_raw_response_move(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.move(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert material is None

    @parametrize
    async def test_streaming_response_move(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.move(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_move(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.materials.with_raw_response.move(
                "",
            )

    @parametrize
    async def test_method_rename(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.rename(
            "id",
        )
        assert material is None

    @parametrize
    async def test_raw_response_rename(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.rename(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert material is None

    @parametrize
    async def test_streaming_response_rename(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.rename(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_rename(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.materials.with_raw_response.rename(
                "",
            )

    @parametrize
    async def test_method_reprocess(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.reprocess(
            "id",
        )
        assert material is None

    @parametrize
    async def test_raw_response_reprocess(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.reprocess(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert material is None

    @parametrize
    async def test_streaming_response_reprocess(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.reprocess(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_reprocess(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.materials.with_raw_response.reprocess(
                "",
            )

    @parametrize
    async def test_method_search(self, async_client: AsyncStudyfetchSDK) -> None:
        material = await async_client.v1.materials.search()
        assert material is None

    @parametrize
    async def test_raw_response_search(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.materials.with_raw_response.search()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        material = await response.parse()
        assert material is None

    @parametrize
    async def test_streaming_response_search(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.materials.with_streaming_response.search() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            material = await response.parse()
            assert material is None

        assert cast(Any, response.is_closed) is True
