# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestScenarios:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: StudyfetchSDK) -> None:
        scenario = client.v1.scenarios.create(
            body="body",
        )
        assert scenario is None

    @parametrize
    def test_raw_response_create(self, client: StudyfetchSDK) -> None:
        response = client.v1.scenarios.with_raw_response.create(
            body="body",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = response.parse()
        assert scenario is None

    @parametrize
    def test_streaming_response_create(self, client: StudyfetchSDK) -> None:
        with client.v1.scenarios.with_streaming_response.create(
            body="body",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: StudyfetchSDK) -> None:
        scenario = client.v1.scenarios.retrieve(
            "id",
        )
        assert scenario is None

    @parametrize
    def test_raw_response_retrieve(self, client: StudyfetchSDK) -> None:
        response = client.v1.scenarios.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = response.parse()
        assert scenario is None

    @parametrize
    def test_streaming_response_retrieve(self, client: StudyfetchSDK) -> None:
        with client.v1.scenarios.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.scenarios.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_update(self, client: StudyfetchSDK) -> None:
        scenario = client.v1.scenarios.update(
            id="id",
            body="body",
        )
        assert scenario is None

    @parametrize
    def test_raw_response_update(self, client: StudyfetchSDK) -> None:
        response = client.v1.scenarios.with_raw_response.update(
            id="id",
            body="body",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = response.parse()
        assert scenario is None

    @parametrize
    def test_streaming_response_update(self, client: StudyfetchSDK) -> None:
        with client.v1.scenarios.with_streaming_response.update(
            id="id",
            body="body",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.scenarios.with_raw_response.update(
                id="",
                body="body",
            )

    @parametrize
    def test_method_list(self, client: StudyfetchSDK) -> None:
        scenario = client.v1.scenarios.list()
        assert scenario is None

    @parametrize
    def test_raw_response_list(self, client: StudyfetchSDK) -> None:
        response = client.v1.scenarios.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = response.parse()
        assert scenario is None

    @parametrize
    def test_streaming_response_list(self, client: StudyfetchSDK) -> None:
        with client.v1.scenarios.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: StudyfetchSDK) -> None:
        scenario = client.v1.scenarios.delete(
            "id",
        )
        assert scenario is None

    @parametrize
    def test_raw_response_delete(self, client: StudyfetchSDK) -> None:
        response = client.v1.scenarios.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = response.parse()
        assert scenario is None

    @parametrize
    def test_streaming_response_delete(self, client: StudyfetchSDK) -> None:
        with client.v1.scenarios.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.scenarios.with_raw_response.delete(
                "",
            )

    @parametrize
    def test_method_get_stats(self, client: StudyfetchSDK) -> None:
        scenario = client.v1.scenarios.get_stats(
            "id",
        )
        assert scenario is None

    @parametrize
    def test_raw_response_get_stats(self, client: StudyfetchSDK) -> None:
        response = client.v1.scenarios.with_raw_response.get_stats(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = response.parse()
        assert scenario is None

    @parametrize
    def test_streaming_response_get_stats(self, client: StudyfetchSDK) -> None:
        with client.v1.scenarios.with_streaming_response.get_stats(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_stats(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.scenarios.with_raw_response.get_stats(
                "",
            )

    @parametrize
    def test_method_submit(self, client: StudyfetchSDK) -> None:
        scenario = client.v1.scenarios.submit(
            "id",
        )
        assert scenario is None

    @parametrize
    def test_raw_response_submit(self, client: StudyfetchSDK) -> None:
        response = client.v1.scenarios.with_raw_response.submit(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = response.parse()
        assert scenario is None

    @parametrize
    def test_streaming_response_submit(self, client: StudyfetchSDK) -> None:
        with client.v1.scenarios.with_streaming_response.submit(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_submit(self, client: StudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.v1.scenarios.with_raw_response.submit(
                "",
            )


class TestAsyncScenarios:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncStudyfetchSDK) -> None:
        scenario = await async_client.v1.scenarios.create(
            body="body",
        )
        assert scenario is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.scenarios.with_raw_response.create(
            body="body",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = await response.parse()
        assert scenario is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.scenarios.with_streaming_response.create(
            body="body",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = await response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        scenario = await async_client.v1.scenarios.retrieve(
            "id",
        )
        assert scenario is None

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.scenarios.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = await response.parse()
        assert scenario is None

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.scenarios.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = await response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.scenarios.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_update(self, async_client: AsyncStudyfetchSDK) -> None:
        scenario = await async_client.v1.scenarios.update(
            id="id",
            body="body",
        )
        assert scenario is None

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.scenarios.with_raw_response.update(
            id="id",
            body="body",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = await response.parse()
        assert scenario is None

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.scenarios.with_streaming_response.update(
            id="id",
            body="body",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = await response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.scenarios.with_raw_response.update(
                id="",
                body="body",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncStudyfetchSDK) -> None:
        scenario = await async_client.v1.scenarios.list()
        assert scenario is None

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.scenarios.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = await response.parse()
        assert scenario is None

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.scenarios.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = await response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        scenario = await async_client.v1.scenarios.delete(
            "id",
        )
        assert scenario is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.scenarios.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = await response.parse()
        assert scenario is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.scenarios.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = await response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.scenarios.with_raw_response.delete(
                "",
            )

    @parametrize
    async def test_method_get_stats(self, async_client: AsyncStudyfetchSDK) -> None:
        scenario = await async_client.v1.scenarios.get_stats(
            "id",
        )
        assert scenario is None

    @parametrize
    async def test_raw_response_get_stats(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.scenarios.with_raw_response.get_stats(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = await response.parse()
        assert scenario is None

    @parametrize
    async def test_streaming_response_get_stats(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.scenarios.with_streaming_response.get_stats(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = await response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_stats(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.scenarios.with_raw_response.get_stats(
                "",
            )

    @parametrize
    async def test_method_submit(self, async_client: AsyncStudyfetchSDK) -> None:
        scenario = await async_client.v1.scenarios.submit(
            "id",
        )
        assert scenario is None

    @parametrize
    async def test_raw_response_submit(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.scenarios.with_raw_response.submit(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        scenario = await response.parse()
        assert scenario is None

    @parametrize
    async def test_streaming_response_submit(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.scenarios.with_streaming_response.submit(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            scenario = await response.parse()
            assert scenario is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_submit(self, async_client: AsyncStudyfetchSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.v1.scenarios.with_raw_response.submit(
                "",
            )
