# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from studyfetch_sdk import StudyfetchSDK, AsyncStudyfetchSDK

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestUsage:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_get_stats(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.get_stats()
        assert usage is None

    @parametrize
    def test_method_get_stats_with_all_params(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.get_stats(
            end_date="endDate",
            group_id="groupId",
            start_date="startDate",
            user_id="userId",
        )
        assert usage is None

    @parametrize
    def test_raw_response_get_stats(self, client: StudyfetchSDK) -> None:
        response = client.v1.usage.with_raw_response.get_stats()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = response.parse()
        assert usage is None

    @parametrize
    def test_streaming_response_get_stats(self, client: StudyfetchSDK) -> None:
        with client.v1.usage.with_streaming_response.get_stats() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_get_summary(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.get_summary(
            end_date="endDate",
            period="hourly",
            start_date="startDate",
        )
        assert usage is None

    @parametrize
    def test_method_get_summary_with_all_params(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.get_summary(
            end_date="endDate",
            period="hourly",
            start_date="startDate",
            group_by="user",
        )
        assert usage is None

    @parametrize
    def test_raw_response_get_summary(self, client: StudyfetchSDK) -> None:
        response = client.v1.usage.with_raw_response.get_summary(
            end_date="endDate",
            period="hourly",
            start_date="startDate",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = response.parse()
        assert usage is None

    @parametrize
    def test_streaming_response_get_summary(self, client: StudyfetchSDK) -> None:
        with client.v1.usage.with_streaming_response.get_summary(
            end_date="endDate",
            period="hourly",
            start_date="startDate",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_list_events(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.list_events()
        assert usage is None

    @parametrize
    def test_method_list_events_with_all_params(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.list_events(
            end_date="endDate",
            event_type="material_created",
            group_id="groupId",
            limit=1,
            offset=0,
            resource_id="resourceId",
            start_date="startDate",
            user_id="userId",
        )
        assert usage is None

    @parametrize
    def test_raw_response_list_events(self, client: StudyfetchSDK) -> None:
        response = client.v1.usage.with_raw_response.list_events()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = response.parse()
        assert usage is None

    @parametrize
    def test_streaming_response_list_events(self, client: StudyfetchSDK) -> None:
        with client.v1.usage.with_streaming_response.list_events() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_track_chat(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.track_chat(
            input_tokens=0,
            model="openai:gpt-4.1",
            output_tokens=0,
            session_id="sessionId",
        )
        assert usage is None

    @parametrize
    def test_method_track_chat_with_all_params(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.track_chat(
            input_tokens=0,
            model="openai:gpt-4.1",
            output_tokens=0,
            session_id="sessionId",
            component_id="componentId",
            group_id="groupId",
            metadata={},
            reasoning_tokens=0,
            user_id="userId",
        )
        assert usage is None

    @parametrize
    def test_raw_response_track_chat(self, client: StudyfetchSDK) -> None:
        response = client.v1.usage.with_raw_response.track_chat(
            input_tokens=0,
            model="openai:gpt-4.1",
            output_tokens=0,
            session_id="sessionId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = response.parse()
        assert usage is None

    @parametrize
    def test_streaming_response_track_chat(self, client: StudyfetchSDK) -> None:
        with client.v1.usage.with_streaming_response.track_chat(
            input_tokens=0,
            model="openai:gpt-4.1",
            output_tokens=0,
            session_id="sessionId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_track_event(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.track_event(
            event_type="material_created",
        )
        assert usage is None

    @parametrize
    def test_method_track_event_with_all_params(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.track_event(
            event_type="material_created",
            cache_hit=True,
            component_name="componentName",
            component_type="componentType",
            content_size=0,
            endpoint="endpoint",
            file_size=0,
            file_type="fileType",
            group_id="groupId",
            input_tokens=0,
            ip_address="ipAddress",
            metadata={},
            method="method",
            model="openai:gpt-4.1",
            output_tokens=0,
            performance_data={},
            reasoning_tokens=0,
            resource_id="resourceId",
            resource_type="resourceType",
            response_time=0,
            session_id="sessionId",
            status_code=0,
            total_tokens=0,
            user_agent="userAgent",
            user_id="userId",
        )
        assert usage is None

    @parametrize
    def test_raw_response_track_event(self, client: StudyfetchSDK) -> None:
        response = client.v1.usage.with_raw_response.track_event(
            event_type="material_created",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = response.parse()
        assert usage is None

    @parametrize
    def test_streaming_response_track_event(self, client: StudyfetchSDK) -> None:
        with client.v1.usage.with_streaming_response.track_event(
            event_type="material_created",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_track_performance(self, client: StudyfetchSDK) -> None:
        usage = client.v1.usage.track_performance()
        assert usage is None

    @parametrize
    def test_raw_response_track_performance(self, client: StudyfetchSDK) -> None:
        response = client.v1.usage.with_raw_response.track_performance()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = response.parse()
        assert usage is None

    @parametrize
    def test_streaming_response_track_performance(self, client: StudyfetchSDK) -> None:
        with client.v1.usage.with_streaming_response.track_performance() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True


class TestAsyncUsage:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_get_stats(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.get_stats()
        assert usage is None

    @parametrize
    async def test_method_get_stats_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.get_stats(
            end_date="endDate",
            group_id="groupId",
            start_date="startDate",
            user_id="userId",
        )
        assert usage is None

    @parametrize
    async def test_raw_response_get_stats(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.usage.with_raw_response.get_stats()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = await response.parse()
        assert usage is None

    @parametrize
    async def test_streaming_response_get_stats(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.usage.with_streaming_response.get_stats() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = await response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_get_summary(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.get_summary(
            end_date="endDate",
            period="hourly",
            start_date="startDate",
        )
        assert usage is None

    @parametrize
    async def test_method_get_summary_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.get_summary(
            end_date="endDate",
            period="hourly",
            start_date="startDate",
            group_by="user",
        )
        assert usage is None

    @parametrize
    async def test_raw_response_get_summary(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.usage.with_raw_response.get_summary(
            end_date="endDate",
            period="hourly",
            start_date="startDate",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = await response.parse()
        assert usage is None

    @parametrize
    async def test_streaming_response_get_summary(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.usage.with_streaming_response.get_summary(
            end_date="endDate",
            period="hourly",
            start_date="startDate",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = await response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_list_events(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.list_events()
        assert usage is None

    @parametrize
    async def test_method_list_events_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.list_events(
            end_date="endDate",
            event_type="material_created",
            group_id="groupId",
            limit=1,
            offset=0,
            resource_id="resourceId",
            start_date="startDate",
            user_id="userId",
        )
        assert usage is None

    @parametrize
    async def test_raw_response_list_events(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.usage.with_raw_response.list_events()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = await response.parse()
        assert usage is None

    @parametrize
    async def test_streaming_response_list_events(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.usage.with_streaming_response.list_events() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = await response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_track_chat(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.track_chat(
            input_tokens=0,
            model="openai:gpt-4.1",
            output_tokens=0,
            session_id="sessionId",
        )
        assert usage is None

    @parametrize
    async def test_method_track_chat_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.track_chat(
            input_tokens=0,
            model="openai:gpt-4.1",
            output_tokens=0,
            session_id="sessionId",
            component_id="componentId",
            group_id="groupId",
            metadata={},
            reasoning_tokens=0,
            user_id="userId",
        )
        assert usage is None

    @parametrize
    async def test_raw_response_track_chat(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.usage.with_raw_response.track_chat(
            input_tokens=0,
            model="openai:gpt-4.1",
            output_tokens=0,
            session_id="sessionId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = await response.parse()
        assert usage is None

    @parametrize
    async def test_streaming_response_track_chat(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.usage.with_streaming_response.track_chat(
            input_tokens=0,
            model="openai:gpt-4.1",
            output_tokens=0,
            session_id="sessionId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = await response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_track_event(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.track_event(
            event_type="material_created",
        )
        assert usage is None

    @parametrize
    async def test_method_track_event_with_all_params(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.track_event(
            event_type="material_created",
            cache_hit=True,
            component_name="componentName",
            component_type="componentType",
            content_size=0,
            endpoint="endpoint",
            file_size=0,
            file_type="fileType",
            group_id="groupId",
            input_tokens=0,
            ip_address="ipAddress",
            metadata={},
            method="method",
            model="openai:gpt-4.1",
            output_tokens=0,
            performance_data={},
            reasoning_tokens=0,
            resource_id="resourceId",
            resource_type="resourceType",
            response_time=0,
            session_id="sessionId",
            status_code=0,
            total_tokens=0,
            user_agent="userAgent",
            user_id="userId",
        )
        assert usage is None

    @parametrize
    async def test_raw_response_track_event(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.usage.with_raw_response.track_event(
            event_type="material_created",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = await response.parse()
        assert usage is None

    @parametrize
    async def test_streaming_response_track_event(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.usage.with_streaming_response.track_event(
            event_type="material_created",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = await response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_track_performance(self, async_client: AsyncStudyfetchSDK) -> None:
        usage = await async_client.v1.usage.track_performance()
        assert usage is None

    @parametrize
    async def test_raw_response_track_performance(self, async_client: AsyncStudyfetchSDK) -> None:
        response = await async_client.v1.usage.with_raw_response.track_performance()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        usage = await response.parse()
        assert usage is None

    @parametrize
    async def test_streaming_response_track_performance(self, async_client: AsyncStudyfetchSDK) -> None:
        async with async_client.v1.usage.with_streaming_response.track_performance() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            usage = await response.parse()
            assert usage is None

        assert cast(Any, response.is_closed) is True
